@@ -18,13 +18,6 @@ class Qiniu(BackendBase):
         self.domain = domain
         self.default_bucket = default_bucket
         self.bucket = BucketManager(self.auth)
-
-        zone = Zone(
-            up_host='https://up.qiniup.com',
-            up_host_backup='https://upload.qiniup.com',
-            io_host='http://iovip.qbox.me',
-            scheme='https')
-        set_default(default_zone=zone)
     
     def get_token(self, filename):
         return self.auth.upload_token(self.default_bucket, filename)
@@ -44,7 +37,7 @@ class Qiniu(BackendBase):
             token = self.auth.upload_token(self.default_bucket, b_name)
             print('upload token acquired -> {}'.format(token))
             print('uploading...')
-            ret, info = put_file(token, b_name, file, version='v2')
+            ret, info = put_file(token, b_name, file)
             if ret is not None:
                 print('upload success.')
                 return True, '{}/{}'.format(_bucket, bucket_name)
